%define _with_repolib 1

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define version_maj  1
%define version_min  2
%define version_rev  04
%define version_post p02
%define version_full %{version_maj}.%{version_min}_%{version_rev}-%{version_post}


Summary:        GlassFish JSF
Name:           glassfish-jsf
Version:        %{version_maj}.%{version_min}_%{version_rev}
Release:        1.%{version_post}.0jpp.ep1.18%{?dist}
Epoch:          0
License:        CDDL
Group:          Development/Java
URL:            https://javaserverfaces.dev.java.net/

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch:      noarch

Source0:        %{name}-%{version}.tar.gz
# - http://download.java.net/maven/1/javax.faces/java-sources/jsf-api-1.2_04-p02-sources.jar
# - http://download.java.net/maven/1/javax.faces/java-sources/jsf-impl-1.2_04-p02-sources.jar

Source1:        %{name}-%{version}-impl-overlay.jar
# FIXME:
# Because of the difficulty in creating a reproducible build which replicates
# Sun's binary releases, we're having to fake it a bit. Source1 contains all
# of the non-classfiles (.properties, .tld, .xsd, etc.) present in Sun's
# binary jsf-impl.jar, and was produced using the following script. This JAR
# should probably be regenerated when upgrading this package to newer sources.
# ----------------------------------------------------------------------------
# #!/bin/bash
# 
# # Name of working directory, will be created in pwd
# WORKDIR='work'
# 
# # Name of output JAR, will be created in pwd
# OUTJAR='jsf-impl-overlay.jar'
# 
# # The file to be downloaded. (This URL was obtained from the page at
# # https://javaserverfaces.dev.java.net/servlets/ProjectDocumentList)
# URLROOT='https://javaserverfaces.dev.java.net/files/documents/1866/58375'
# DLZIP='jsf-1_2_04-p02.zip'
# 
# # The file (and path to it) to be extracted from the downloaded ZIP
# ZIPPATH='jsf-1.2_04-b16-p02/lib'
# IMPLJAR='jsf-impl.jar'
# 
# ###
# 
# wget $URLROOT/$DLZIP && \
# unzip -p $DLZIP $ZIPPATH/$IMPLJAR > $IMPLJAR && \
# rm -rf $WORKDIR && \ 
# mkdir $WORKDIR && \
# pushd $WORKDIR && \
#   unzip ../$IMPLJAR && \
#   jar cvf ../$OUTJAR `find . -type f '!' -iname *.class \
#     '!' -wholename '*com/sun/org/apache*'` && \
# popd
# ----------------------------------------------------------------------------

Source2:        %{name}-%{version}-component-info.xml
Source3:        %{name}-%{version}-build.xml

# We're including source for commons-{beanutils,collections,digester,logging}
# because Sun includes them in their binary release and not in the source JAR
Source4:        apache-commons-sources.tar.gz

BuildRequires:  ant
BuildRequires:  servletapi6
BuildRequires:  glassfish-jstl
BuildRequires:  jbossweb
BuildRequires:  apache-portlet-1.0-api

# The following are for the commons logging build
BuildRequires:  avalon-logkit
BuildRequires:  avalon-framework
BuildRequires:  log4j


%description
The JSF 1.2 implementation. NB: We've omitted the classes
Jetty6InjectionProvider and GlassFishInjectionProvider from the
package com.sun.faces.vendor.


%define repodir %{_javadir}/repository.jboss.com/sun-jsf/%{version_full}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif


%prep
%setup

# -api:
pushd api
    mkdir src
    pushd src
        jar xvf ../jsf-api-%{version_full}-sources.jar
    popd

    sed -i "s|@API-DIR@|`pwd`|g" %{SOURCE3}
popd

# -impl:
pushd impl
    mkdir src build
    pushd src
        jar xvf ../jsf-impl-%{version_full}-sources.jar
        
        # We don't need these InjectionProviders, we're removing them because
        # it would be too much trouble to provide their build dependencies.
        rm -f com/sun/faces/vendor/{Jetty6,GlassFish}InjectionProvider.java

        ## We're using jakarta-commons- packages, we have no need for Sun's
        ## naming nonsense
        #sed -i 's/com.sun.\(org.apache\)/\1/g' `grep -lr "com.sun.org.apache" *`
    popd

    overlay=%{SOURCE1}
    sed -i "s|@IMPL-DIR@|`pwd`|g;s|@IMPL-OVERLAY@|$overlay|g" %{SOURCE3}
 
popd

# component-info:
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE2}

sed -i s/@VERSION@/%{version_full}-brew/g %{SOURCE2}

# commons:
mkdir commons
pushd commons
    tar xzvf %{SOURCE4}
    
    commonspath=`build-classpath log4j`:`build-classpath avalon-logkit`:`build-classpath avalon-framework`
    sed -i "s|@COMMONS-PATH@|$commonspath|g" build.xml

    # Move everything over to the com.sun.org namespace so that we can imitate Sun's binary releases
    mkdir -p src/com/sun
    mv src/org src/com/sun/
    # Stealing this from the classpathx-mail spec file
    perl -p -i -e 's/org(.)apache(.)commons/com${1}sun${1}org${1}apache${1}commons/' `grep org.apache.commons -lr *`

    ant jar
popd commons

%build
ant -f %{SOURCE3} jar

%install
rm -rf $RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/
install -p -m 0644 api/jsf-api.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-api-%{version_full}.jar
install -p -m 0644 impl/jsf-impl.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-impl-%{version_full}.jar

pushd $RPM_BUILD_ROOT%{_javadir}
    ln -sf %{name}-api-%{version_full}.jar  %{name}-api.jar
    ln -sf %{name}-impl-%{version_full}.jar %{name}-impl.jar
    
    ln -sf %{name}-api-%{version_full}.jar  jsf-api.jar
    ln -sf %{name}-impl-%{version_full}.jar jsf-impl.jar
popd



%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{SOURCE2} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE3} $RPM_BUILD_ROOT%{repodirsrc}
	cp --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-api.jar $RPM_BUILD_ROOT%{repodirlib}
	cp --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-impl.jar $RPM_BUILD_ROOT%{repodirlib}
%endif

%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(0644,root,root,0755)
%{_javadir}/jsf-api.jar
%{_javadir}/%{name}-api.jar
%{_javadir}/%{name}-api-%{version_full}.jar
%{_javadir}/jsf-impl.jar
%{_javadir}/%{name}-impl.jar
%{_javadir}/%{name}-impl-%{version_full}.jar



%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Fri Nov 30 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.18
- Adding a bunch of Apache commons source to compile in with the -impl stuff

* Thu Nov 29 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.17
- Adding an "overlay" JAR containing all of the non-classfiles which our -impl
  JAR is missing when compared to Sun's (see also, note at Source1)
- Adding the overlay jar and -build.xml to %%{repodirsrc}

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.16
- Adding jbossweb's annotations-api.jar to the impl's classpath

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.15
- Fixing mistakely clobbered @API-DIR@ and @IMPL-DIR@ targets in -build.xml

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.14
- First complete build

* Fri Nov 23 2007 Fernando Nasser <fnasser@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.13
- Revert to sun-jaf name to please buildmagic

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.12
- Added -brew suffix.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.11
- %%{release} twiddling (to appease the packaging gods)

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.11.p02
- Fixed build.xml path confusion.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.10.p02
- Brain not work good today. BuildRequiring ant.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.9.p02
- Fixed 'make new-source's omission of the jsf-impl JAR from sources

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.8.p02
- Uploaded new (non-broken!) version of Source0

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.7.p02
- Corrected %%install section, and -impl's %%setup

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.6.p02
- Unbreaking the references to the ant buildfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.5.p02
- Using ant rather than inlining the build in the specfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.4.p02
- Changed -api's javac invocation

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.3.p02
- Added -api's sources to its classpath

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.2.p02
- Removed version specification from BR: glassfish-jstl

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.1.p02
- First release. The -api JAR is building, the -impl JAR is not (yet).
